@@ -21,7 +21,7 @@ class Singleton:
 class opFlowLabConfig(Singleton):
     def __init__(self):
         Singleton.__init__(self)
-        if self.hasInstance():
+        if self.hasLoaded():
             pass
         else:
             self.mainFolderPath = None
@@ -69,12 +69,22 @@ class opFlowLabConfig(Singleton):
 
             self.action_count = 1
 
+            self.settingsPath = os.path.join(os.path.expanduser("~"), "OpFlowLab_settings.yaml")
+            self.executablePath = None
+
+            self.loadSettings()
+
+            self._loaded = True
+
     def getInstance(self):
         return self._instance
 
     def hasInstance(self):
         return hasattr(self, "_instance")
 
+    def hasLoaded(self):
+        return hasattr(self, "_loaded")
+
     def setattr(self, attr, value):
         self.__setattr__(attr, value)
         if self.hasInstance:
@@ -132,6 +142,34 @@ class opFlowLabConfig(Singleton):
 
         self.action_count += 1
 
+    def loadSettings(self):
+        yaml = YAML()
+
+        if not os.path.isfile(self.settingsPath):
+            self.saveSettings()
+
+        else:
+            with open(self.settingsPath, 'r') as file:
+                settings_dict = yaml.load(file)
+
+            self.executablePath = settings_dict["executablePath"]
+            self.flowMatch_folder = settings_dict["flowMatch_folder"]
+            self.flowPath_folder = settings_dict["flowPath_folder"]
+            self.flowWarp_folder = settings_dict["flowWarp_folder"]
+            self.flowTracer_folder = settings_dict["flowTracer_folder"]
+
+    def saveSettings(self):
+        yaml = YAML()
+
+        settings_dict = {"executablePath": self.executablePath,
+                         "flowMatch_folder": self.flowMatch_folder,
+                         "flowPath_folder": self.flowPath_folder,
+                         "flowWarp_folder": self.flowWarp_folder,
+                         "flowTracer_folder": self.flowTracer_folder}
+
+        with open(self.settingsPath, 'w') as file:
+            yaml.dump(settings_dict, file)
+
 
 class opFlowLabWorker(QObject):
     progressSignal = pyqtSignal(int)
