@@ -1110,28 +1110,4 @@ class OpFlowLab:
                                           smoothing=smoothing,
                                           colormap=plt.cm.coolwarm,
                                           colormap_min=vmin, colormap_max=vmax,
-                                          )
-
-
-if __name__ == '__main__':
-    main_folderpath = r"K:\Matt\ck\20200918_mdckh1\GFP\resliced2"
-    image_filepath = os.path.join(main_folderpath, "Fused.tif")
-
-    opflow = OpFlowLab(main_folderpath, image_filepath,
-                            "NvidiaOF_Slow", None,  # r"Reverse/NvidiaOF_Slow",
-                       None,  # "Stardist_mask",
-                       velocity_type="dense", velocity_ext_type="*.bin", image_ext_type="*.tif",
-                       velocity_dtype="float16", kernel_size=5, )
-
-    # OpFlowLab.plot_colorwheel(OpFlowLab.main_folder)
-
-    opflow.flowTracer_function(
-        tracer_no=10000,
-        start_frame=5,
-        save_initial_tracer_pos=True,
-        output_folder="tracer")
-
-    # OpFlowLab.plot_curl()
-    # OpFlowLab.plot_divergence()
-    # OpFlowLab.plot_simple_shear()
-    # OpFlowLab.plot_lic()
+                                          )
\ No newline at end of file
